@@ -1,3 +1,6 @@
+# -*- coding: utf-8
+from __future__ import unicode_literals
+
 import sys
 
 GREY    = 30
@@ -13,7 +16,7 @@ NORMAL = 0
 BOLD = 1
 
 
-class ColoredString(str):
+class ColoredString(type('')):
     color = WHITE
     weight = NORMAL
     def __str__(self):
